@@ -2,6 +2,7 @@
 
 import re
 import shlex
+import sys
 from collections.abc import Iterable
 from dataclasses import (
     dataclass,
@@ -9,6 +10,11 @@ from dataclasses import (
 )
 from typing import Any
 
+if sys.version_info >= (3, 11):
+    from typing import Self
+else:
+    from typing_extensions import Self
+
 from . import (
     constants,
     utils,
@@ -144,7 +150,7 @@ class Statement(str):  # noqa: SLOT000
     # Used in JSON dictionaries
     _args_field = 'args'
 
-    def __new__(cls, value: object, *_pos_args: Any, **_kw_args: Any) -> 'Statement':
+    def __new__(cls, value: object, *_pos_args: Any, **_kw_args: Any) -> Self:
         """Create a new instance of Statement.
 
         We must override __new__ because we are subclassing `str` which is
