@@ -1,21 +1,17 @@
 #!/usr/bin/env python
-# coding=utf-8
-"""
-A simple example demonstrating how to enable tab completion by assigning a completer function to do_* commands.
+"""A simple example demonstrating how to enable tab completion by assigning a completer function to do_* commands.
 This also demonstrates capabilities of the following completer features included with cmd2:
 - CompletionError exceptions
 - delimiter_complete()
 - flag_based_complete() (see note below)
-- index_based_complete() (see note below)
+- index_based_complete() (see note below).
 
 flag_based_complete() and index_based_complete() are basic methods and should only be used if you are not
 familiar with argparse. The recommended approach for tab completing positional tokens and flags is to use
 argparse-based completion. For an example integrating tab completion with argparse, see argparse_completion.py
 """
+
 import functools
-from typing import (
-    List,
-)
 
 import cmd2
 
@@ -34,19 +30,19 @@ file_strs = [
 
 
 class BasicCompletion(cmd2.Cmd):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-    def do_flag_based(self, statement: cmd2.Statement):
+    def do_flag_based(self, statement: cmd2.Statement) -> None:
         """Tab completes arguments based on a preceding flag using flag_based_complete
         -f, --food [completes food items]
         -s, --sport [completes sports]
-        -p, --path [completes local file system paths]
+        -p, --path [completes local file system paths].
         """
-        self.poutput("Args: {}".format(statement.args))
+        self.poutput(f"Args: {statement.args}")
 
-    def complete_flag_based(self, text, line, begidx, endidx) -> List[str]:
-        """Completion function for do_flag_based"""
+    def complete_flag_based(self, text, line, begidx, endidx) -> list[str]:
+        """Completion function for do_flag_based."""
         flag_dict = {
             # Tab complete food items after -f and --food flags in command line
             '-f': food_item_strs,
@@ -61,12 +57,12 @@ class BasicCompletion(cmd2.Cmd):
 
         return self.flag_based_complete(text, line, begidx, endidx, flag_dict=flag_dict)
 
-    def do_index_based(self, statement: cmd2.Statement):
-        """Tab completes first 3 arguments using index_based_complete"""
-        self.poutput("Args: {}".format(statement.args))
+    def do_index_based(self, statement: cmd2.Statement) -> None:
+        """Tab completes first 3 arguments using index_based_complete."""
+        self.poutput(f"Args: {statement.args}")
 
-    def complete_index_based(self, text, line, begidx, endidx) -> List[str]:
-        """Completion function for do_index_based"""
+    def complete_index_based(self, text, line, begidx, endidx) -> list[str]:
+        """Completion function for do_index_based."""
         index_dict = {
             1: food_item_strs,  # Tab complete food items at index 1 in command line
             2: sport_item_strs,  # Tab complete sport items at index 2 in command line
@@ -75,20 +71,19 @@ class BasicCompletion(cmd2.Cmd):
 
         return self.index_based_complete(text, line, begidx, endidx, index_dict=index_dict)
 
-    def do_delimiter_complete(self, statement: cmd2.Statement):
-        """Tab completes files from a list using delimiter_complete"""
-        self.poutput("Args: {}".format(statement.args))
+    def do_delimiter_complete(self, statement: cmd2.Statement) -> None:
+        """Tab completes files from a list using delimiter_complete."""
+        self.poutput(f"Args: {statement.args}")
 
     # Use a partialmethod to set arguments to delimiter_complete
     complete_delimiter_complete = functools.partialmethod(cmd2.Cmd.delimiter_complete, match_against=file_strs, delimiter='/')
 
-    def do_raise_error(self, statement: cmd2.Statement):
-        """Demonstrates effect of raising CompletionError"""
-        self.poutput("Args: {}".format(statement.args))
+    def do_raise_error(self, statement: cmd2.Statement) -> None:
+        """Demonstrates effect of raising CompletionError."""
+        self.poutput(f"Args: {statement.args}")
 
-    def complete_raise_error(self, text, line, begidx, endidx) -> List[str]:
-        """
-        CompletionErrors can be raised if an error occurs while tab completing.
+    def complete_raise_error(self, _text, _line, _begidx, _endidx) -> list[str]:
+        """CompletionErrors can be raised if an error occurs while tab completing.
 
         Example use cases
             - Reading a database to retrieve a tab completion data set failed
